#!/bin/sh

LOCK_FILE=/tmp/update.lock
UPD_EXEC=/usr/sbin/os-update

if [ -x /tmp/update_finished ]; then
    rm /tmp/update_finished
fi

if [ -f $LOCK_FILE ]; then
    echo 1>&2 "Lock file exists!" > /tmp/update_failed
    exit 127
fi

if [ $# -ne 1 ]; then
    echo 1>&2 "$0 Usage: update.sh <update archive>"
    touch /tmp/update_failed
    exit 127
fi 

if [ ! -f $1 -o ! -r $1 ]; then
    echo 1>&2 "Unable to read $1" > /tmp/update_failed
    exit 127
else
    unzip $1 -d /tmp >/dev/null
fi

if [ ! -d /tmp/update ]; then
    echo 1>&2 "Update directory does not exist!" > /tmp/update_failed
    exit 127
fi

if [ ! -x $UPD_EXEC ]; then
    echo 1>&2 "$UPD_EXEC has no execute privileges or does not exists" > /tmp/update_failed
    exit 127
fi

if [ -e '/tmp/update/run.sh' ]; then
	chmod +x /tmp/update/run.sh
fi

if [ -x '/tmp/update/run.sh' ]; then

	touch $LOCK_FILE
	test -x /etc/rc.d/init.d/os && /etc/rc.d/init.d/os stop
	test -x /etc/rc.d/init.d/osscan && /etc/rc.d/init.d/osscan stop
	
	#do update loop here
	/tmp/update/run.sh
	
	test -x /etc/rc.d/init.d/os && /etc/rc.d/init.d/os start
	test -x /etc/rc.d/init.d/osscan && /etc/rc.d/init.d/osscan start

	rm -rf /tmp/update
	rm $LOCK_FILE
	
	touch /tmp/update_finished
else
	touch /tmp/update_failed
	echo "/tmp/update/run.sh does not exist or is not executable!"
fi

exit 0
